#
# spec file for package python-sambacc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global bname sambacc

Name:           python-%{bname}
Version:        v0.6+git.60.2f89a38
Release:        1.1
Summary:        Samba Container Configurator
License:        GPL-3.0-or-later
URL:            https://github.com/samba-in-kubernetes/sambacc
Source:         %{bname}-%{version}.tar.bz2
BuildArch:      noarch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
Requires:       python3-pyxattr
Requires:       samba-python3

%python_subpackages

%description
A Python library intended to act as a bridge between a container
environment and Samba servers and utilities. It aims to consolidate, coordinate and
automate all of the low level steps of setting up smbd, users, groups, and other
supporting components.

%package -n %{bname}
Summary:        %{summary}
Requires:       python3-%{bname}

%description -n %{bname}
A set of CLI tools intended to act as a bridge between a container
environment and Samba servers and utilities. It aims to consolidate, coordinate and
automate all of the low level steps of setting up smbd, users, groups, and other
supporting components.

%prep
%autosetup -n %{bname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/%{bname}-*.dist-info
%python_expand find %{buildroot}%{$python_sitelib} -name *.pyc -delete
sed -i 's;python%{python_version};python3;g' %{buildroot}/%{_bindir}/samba-container
sed -i 's;python%{python_version};python3;g' %{buildroot}/%{_bindir}/samba-dc-container

%files %{python_files}
%{python_sitelib}/%{bname}

%files -n %{bname}
%doc README.*
%{_bindir}/samba-container
%{_bindir}/samba-dc-container
%{_bindir}/samba-remote-control
%{_datadir}/%{bname}

%changelog
* Sat Jun 21 2025 Noel Power <nopower@suse.com>
- Update to version v0.6+git.60.2f89a38:
  * tests: add a test case for the ensure_ctdb_port_in_services func
  * sambacc: add a function to alter /etc/services for ctdb port
  * sambacc: add a ctdb port configuration value
  * samba_cmds: Switch ctdb to CommandArgs type
  * samba_cmds: Switch wbinfo to CommandArgs type
  * samba_cmds: Modify execute() to accept CommandArgs
  * tests: test session crypto info fetched from grpc server
  * grpc: add session crypto information to grpc server
  * grpc: add session crypto message to control.proto
  * tests: add test coverage for backend session crypto
  * grpc: add support for session crypto info to backend.py
  * grpc: remove junk values from backend Versions object
  * mergify: Restrict the addition of "priority-review" label
  * github: Update mergify rules with symbolic fedora test jobs
  * workflows: Dynamically detect fedora versions for test matrix
  * extras: update python-sambacc.spec for new grpc extra
  * tox.ini: include grpc libs for unit tests
  * setup.cfg: add new modules, entrypoint, extras
  * commands/remotecontrol: create remote control command
  * tests: add test_grpc_backend.py to test server backend module
  * tests: add test_grpc_server.py to test grpc server behavior
  * grpc: add server.py for managing the grpc server
  * grpc: add backend.py for interfacing with samba commands
  * grpc/generated: add generated grpc files
  * tox.ini: add new environments for generating grpc related files
  * grpc/protobufs: add initial .proto file
  * grpc: establish a location for grpc related code and files
  * tox.ini: support mypy checking for files using grpc libs
  * pyproject.toml: exclude generated files from mypy check
  * tox.ini: exclude files that grpc toolchain will generate
  * sambacc: add smbstatus command to samba_cmds.py
  * tox: split formatting testenv from flake8
  * sambacc/commands: makde the dc main command setup less special
  * sambacc/commands: clean up imports used only for commands
  * sambacc/commands: add include function to help clarify import reasons
  * sambacc/commands: add docstring for global_args
  * sambacc/commands: add docstring and fix type hint for enable_logging
  * sambacc/commands: update pre_action type hint
  * sambacc/commands: add docstring and type hint to env_to_cli function
  * sambacc/commands: add docstring and type hint to from_env function
  * sambacc/commands: add type hints and docstring to split_entries
  * sambacc/common: create common.py from common parts of main.py
  * sambacc/commands: clone ceph_id function into cli.py
  * sambacc/commands: remove some unnecessary ellipses
  * commands: invalidate cached config when node is not ctdb leader
  * tests/container: set a vendor suffix with VENDOR_DIST_SUFFIX
  * extras: allow a vendor dist suffix field in the spec file
  * sambacc: fix a pair of flake8 errors
  * tests: add test funcs for odj join source
  * sambacc/commands: add odj support to the join command line
  * sambacc: add odj to the core join class
  * sambacc: remove add_source method from Joiner
  * commands: handle /usr/etc/nsswitch.conf
  * commands: when possible skip ceph service registration for mutex helper
  * sambacc: add a specifics flag for mutex helper registration option
* Wed Feb 26 2025 jeffm@suse.com
- Update to version v0.6+git.5.aa9a005:
  * commands: fix a mypy failure in the ctdb commands module
  * tests/container: update base image to fedora 41
  * github: update mergify rules to use fedora 41, not 39
  * workflows: update test matrix to use fedora 41
  * ctdb: handle nodes with "GONE" state when listing CTDB nodes
  * ctdb: Leave CTDB log levels at their original defaults
  * commands: add retries to ctdb-must-have-nodes command
  * ctdb: improve hostname lookup for ctdb nodes
  * tests/container: add rhel support to rpm builds
  * sambacc: fix constructing interface list for ctdb public_addresses
  * commands: pass instance config to ctdb etc setup
  * sambacc: add public addresses support to ctdb module
  * sambacc: add config placeholder for ctdb public address config
  * sambacc: avoid logging an error if cluster is being torn down
  * github: Update mergify config to replace deprecated attributes
  * sambacc: add a retry loop to ctdb.monitor_cluster_meta_changes
  * commands: time out waiting for conditions after 5min
  * commands: add ability to wait for ctdb when running smbd/winbindd
  * sambacc: move ctdb pnn fetching commands into functions
  * commands: add ctdb-list-nodes subcommand
  * sambacc: add nodes command to ctdb configuration if needed
  * sambacc: add ability to write to an open file to cluster_meta_to_nodes
  * commands: add ctdb-monitor-nodes command
  * sambacc: add monitor_cluster_meta_changes function
  * sambacc: simplify _cluster_meta_to_ctdb_nodes function
  * sambacc: split out some potentially common ctdb logic into funcs
  * commands: improve ctdb_manage_nodes doc comment
  * sambacc: rename function to manage_cluster_meta_updates
  * commands: encapsulate retry logic
  * commands: fix incorrect help text for --write-nodes
  * commands: add ctdb-rados-mutex sambacc subcommand
  * sambacc: move rados pesudo-uri parsing to top level function
  * sambacc: add ctdb_mutex_ceph_rados_helper to known commands
  * commands: add --archive option to ctdb-migrate cmd
  * commands: add --write-node option to ctdb-must-have-node cmd
  * sambacc: add archive_tdb function
  * sambacc: add cluster_meta_to_nodes function
  * commands: support acquiring a node number from the environment
  * commands: enable using a rados object uri for ctdb cluster meta
  * sambacc: rename function to enable_rados
  * sambacc: add is_rados_uri helper function
  * sambacc: add cluster meta rados classes
  * sambacc: add get_object method to rados handler class
  * sambacc: add methods for writing and locking RADOSObjectRef
  * sambacc: rename rados object class to RADOSObjectRef
  * commands: prepare ctdb commands for using cluster meta objects
  * sambacc: add monitor_cluster_meta_updates func to ctdb
  * sambacc: replace path key with uri key for ctdb metadata state object
  * sambacc: move important CTDB constants to global vars
  * commands: tweak --skip-if help string
  * commands: add new generic --skip-if command line options
  * tests: add unit tests for skips module
  * commands: add generalized skips feature for sambacc command line
  * tox.ini: update version of black formatter tool
  * commands: document protocol methods
  * smabacc: document protocol methods
  * sambacc: add ClusterMeta protocol to ctdb functions
  * sambacc: add ClusterMetaJSONFile class
  * sambacc: add version wrapper around typing.Self
  * sambacc: simplify the closure function writing ctdb config
  * tox.ini: remove old workaround in schemacheck env
  * tox.ini: Add descriptions to various tox envs
  * mergify: update merge conditions to match test matrix
  * workflows: update test matrix to use fedora 40
  * workflows: disable fail-fast option for distro matrix
  * workflows: upgrade to checkout@v4
  * schema: improve wording in interfaces description field
  * docs: document new interface filtering options
  * schema: schema updates for new interface filtering options
  * commands: allow filtering network interfaces when provisioning ad dc
  * tests: add unit test for new interface filtering func
  * sambacc: add ad dc functions for interface filtering
  * sambacc: add a new dc interface config type
  * tox.ini: add schemaupdate environment
  * schema.yaml: typo fixes
  * tests: add OU support tests
  * sambacc: add organizational unit (OU) support for ad dc configuration
  * samba_cmds: add --debug-stdout flag for samba
  * samba_cmds: move --debuglevel option after positions arguments
  * extras: enable some recommended extras on centos 9
  * tox: stick to black 2023 style for now
  * sambacc: remove extra parens
  * tox: workaround test failures for schemacheck
  * tox: set a max version for black temporarily
  * commands: add option to select debug level logging in sambacc
  * commands: add setting ceph id info via --ceph-id or SAMBACC_CEPH_ID env
  * sambacc: add logging to rados opener
  * sambacc: extend rados opener to support passing client name
  * sambacc: extend rados pseudo-uris to include getting mon config keys
  * commands: pass opener to read_config_files called from update-config
  * container: update default test container version to fedora 39
  * github: update mergify rules to use fedora 39, not 37
  * workflows: update build matrix to use fedora 39, drop fedora 37
  * setup.cfg: fix missing description text
  * docs: add a link to the pypi repository for sambacc to release doc
  * extras: add the optional rados extra to the rpm spec
  * setup.cfg: add a new extra for rados
  * commands: pass an opener to the joiner
  * commands: add a context property returning an opener
  * sambacc: fix join interactive test
  * sambacc: support passing an opener for join source files
  * sambacc: make FileOpener a common type
  * sambacc: do not require coverage for protocol types
  * sambacc: do not require coverage for protocol types
  * tests: add test_url_opener.py
  * tests: add test_rados_opener.py
  * commands: enable url and rados openers for sambacc config
  * sambacc: support passing an opener to configuration reader
  * sambacc: add optional rados support to url opener
  * sambacc: add a URL opener type
  * sambacc: add the concept of an opener type
  * docs: be clearer about what types top-level configs take
  * github: Update mergify rules to match recent changes to ci matrix
  * workflows: minor yaml formatting tweaks
  * workflows: simply workflow with a matrix
  * readme: fix mixed up mark down links
  * tests: Fix a typo in file name
  * commands: update smb.conf post- provision and join funcs
  * tests: add unit tests for smbconf_samba
  * sambacc: add smbconf_samba module to wrap samba smbconf module
  * tests: add unit tests for smbconf_api
  * sambacc: add smbconf_api module for abstract smbconf operations
  * sambacc: do not raise a KeyError if a config lacks globals
  * commands: pass global options to provision and join calls
  * tests: add unit test cases for addc functions
  * sambacc: add common filtering func to AD DC globals
  * sambacc: add options argument to addc join function
  * sambacc: add options argument to addc provision function
  * commands: remove unnecessary protocol function
  * container: update to a still-maintained fedora version
  * tox: fix passing arguments to tox env for pytest
  * gitlint: ignore body lines that are footnotes
  * docs: add a release process document
  * readme: update readme to reflect recent changes
- Updated _service to use manual mode, obs_scm, and use cpio archives
* Wed Feb 28 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add dependency on setuptools.
* Wed May 10 2023 dmulder@suse.com
- Update to version v0.2+git.108.e7850e0:
  * docs: document the availability of yaml and toml formatted confs
  * extras: have rpm spec recommend extras on fedora 37 & later
  * extras: add our toml and yaml extras to the rpm spec
  * tox: get all test envs that install via pip working with extras
  * setup: add extras for toml and yaml
  * tests: support testing toml with tomli or tomllib
  * sambacc: support tomli for reading toml on older versions
  * tests: add test cases for yaml formatted configuration
  * sambacc: add support for reading YAML formatted configs
  * tests: add test cases for toml formatted configuration
  * sambacc: add support for reading TOML formatted configs
  * copr: add .copr/Makefile for building in COPR system
  * container: default to dnf in build script
  * container: more granular controls of build script behavior
  * container: generate a more robust rpm spec file
  * container: make build script a tad more consistent
  * extras: fix a typo in the rpm spec
  * extras: add additional build deps to the rpm spec file
  * extras: add validation extra as an rpm sub package
  * sambacc: make config module robust to unexpected jsonschema versions
* Tue Apr 18 2023 dmulder@suse.com
- Update to version v0.2+git.88.c81c65a:
  * workflows: add a job to check commit messages
  * gitlint: add a .gitlint configuration file
  * tox: add a gitlint environment
  * tox: add an 'extras' to the python package
  * extras: fix a warning when building on fc37
  * extras: use the new py3-sys tox env in the rpm spec file
  * tox: create a new py3-sys environment
  * workflows: do not run push job if test job fails
  * workflows: add test runs for centos stream9 and fedora 37
  * workflows: use non-shallow git checkout to please setuptools_scm
  * container: inform git that our repo path is acceptable
  * container: always run rpm build as part of a normal build
  * tox: remove jsonschema from the tox deps list
  * sambacc: ignore mypy errors if it can't import jsonschema
  * setup.cfg: add sambacc.schema to package list
  * tox: add schemacheck to verify that generated schema data matches yaml
  * tests: add initial tests of json schema validation
  * commands: extend the context protocol with a require_validation method
  * commands: add cli option & env var to control config validation
  * sambacc: add support for json schema based validation of the config
  * tox: add type definition packages for mypy testing with json schema
  * pyproject: do not require typing in the schema dir
  * schema: commit generated python
  * schema: add a python tool to manage schema files
  * schema: add new json-schema based schema files to the tree
  * tests: supply invalid configuration to GloalConfig directly
  * sambacc: add an initial_data argument to GlobalConfig class
  * sambacc: add a JSONData type for convenience
  * tests: fix a typo in a test name
  * sambacc: rename check_config_data to take it private
  * github: sync mergify rules that handle aged PRs
  * docs: fix incorrect version number in configuration.md
* Thu Apr  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Drop empty %%generate_buildrequires section: no code in the
  section produces build deps.
* Mon Feb  6 2023 dmulder@suse.com
- Update to version v0.2+git.56.9d8b892:
  * container: parameterize the sambacc containerfile
  * container: update build.sh with ability to install dependencies
* Mon Jan 30 2023 dmulder@suse.com
- Update to version v0.2+git.54.f426c23:
  * Revert "container: Switch to CentOS Stream 9 as base image"
  * mergify.yml: Fix a typo
  * container: Switch to CentOS Stream 9 as base image
  * github: add mergify configuration YAML file
  * sambacc: re-format with black version 23.1a1
  * docs: add first full document describing JSON config
  * tox.ini: avoid one tox warning when running py3-mypy
  * pyproject: require type annotations for sambacc function defs
  * sambacc: complete type annotations for container_dns.py
  * sambacc: complete type annotations for simple_waiter.py
* Mon Oct 10 2022 David Mulder <dmulder@suse.com>
- Initial commit of sources
